@@ -4,10 +4,8 @@ import sys
 import numpy as np
 
 from MinutiaeClassificator.ClassifyNetWrapper import ClassifyNetWrapper
-from MinutiaeClassificator.utils.image_utils import read_image, show_image
+from MinutiaeClassificator.utils.image_utils import read_image, draw_minutiae
 from MinutiaeClassificator.MinutiaeNetWrapper import MinutiaeNetWrapper
-from MinutiaeClassificator.MinutiaeNet.CoarseNet.MinutiaeNet_utils import draw_minutiae
-
 
 class MinutiaeExtractorWrapper:
     def __init__(self):
@@ -38,19 +36,29 @@ class MinutiaeExtractorWrapper:
     def load_classification_module(self):
         self.__classification_module = ClassifyNetWrapper(self.__classify_net_path)
 
-    def get_classified_minutiae(self, image_path):
+    def get_classified_minutiae(self, image_path, as_image = True):
         image = read_image(image_path)
 
         extracted_minutiae = self.__extract_minutiae(image['image'], image['original_image'])
         classified_minutiae = self.__classify_minutiae(image['original_image'], extracted_minutiae)
 
+        if as_image:
+            image_data = draw_minutiae(image['original_image'], classified_minutiae, 15, True)
+
+            return image_data
+
         return classified_minutiae
 
-    def get_extracted_minutiae(self, image_path):
+    def get_extracted_minutiae(self, image_path, as_image = True):
         image = read_image(image_path)
 
         extracted_minutiae = self.__extract_minutiae(image['image'], image['original_image'])
 
+        if as_image:
+            image_data = draw_minutiae(image['original_image'], extracted_minutiae, 15, True)
+
+            return image_data
+
         return extracted_minutiae
 
 
